@@ -17,15 +17,14 @@ limitations under the License.
 """
 
 import os
-import time
-
 import requests
+import time
 
 from toolium.utils.path_utils import makedirs_safe
 
 # constants
 STATUS_OK = 200
-STATUS_PORT = "8888"
+STATUS_PORT = '8888'
 DOWNLOADS_PATH = u'downloads'
 MP4_EXTENSION = u'mp4'
 LOG_EXTENSION = u'log'
@@ -104,9 +103,10 @@ class Selenoid(object):
                                                 'seconds' % (path_file, took))
                 return True
             except IOError as e:
-                self.driver_wrapper.logger.warn('Error writing downloaded file in "%s":\n %s' % (path_file, e))
+                self.driver_wrapper.logger.warning('Error writing downloaded file in "%s":\n %s' % (path_file, e))
         else:
-            self.driver_wrapper.logger.warn('File "%s" does not exist in the server after %s seconds' % (url, timeout))
+            self.driver_wrapper.logger.warning('File "%s" does not exist in the server after %s seconds' % (url,
+                                                                                                            timeout))
         return False
 
     def __remove_file(self, url):
@@ -133,22 +133,83 @@ class Selenoid(object):
         """
         Is the GGR session still active? Associated to a browser and the sessionId
         Example of GGR status:
-        {"browsers":{"MicrosoftEdge":{"latest":{}},"android":{"8.1":{}},"chrome":{"70.0":{},"latest":{"test_tef":{"count":1,"sessions":[{"caps":{"browserName":"chrome","enableVNC":true,"enableVideo":true,"platform":"ANY","screenResolution":"1280x1024x24","version":"latest","videoName":"selenoide952e551bb9395e16d060f28c54e5d31.mp4","videoScreenSize":"1280x1024"},"container":"8489205e28c9781472e99c3921a6240de3894a3603ed9e187ad6360b6b013b8b","containerInfo":{"id":"8489205e28c9781472e99c3921a6240de3894a3603ed9e187ad6360b6b013b8b","ip":"172.17.0.4"},"id":"1345506093dfed8dbcef610da476911a228ca315978e5464ae49fb1142bbc49b","screen":"1280x1024x24","vnc":true}]}}},"firefox":{"59.0":{},"63.0":{},"64.0":{},"latest":{}},"internet explorer":{"11":{}},"opera":{"56.0":{},"latest":{}},"safari":{"latest":{}}},"pending":0,"queued":0,"total":30,"used":1}
+        {
+          "browsers": {
+            "MicrosoftEdge": {
+              "latest": {}
+            },
+            "android": {
+              "8.1": {}
+            },
+            "chrome": {
+              "70.0": {},
+              "latest": {
+                "test_tef": {
+                  "count": 1,
+                  "sessions": [
+                    {
+                      "caps": {
+                        "browserName": "chrome",
+                        "enableVNC": true,
+                        "enableVideo": true,
+                        "platform": "ANY",
+                        "screenResolution": "1280x1024x24",
+                        "version": "latest",
+                        "videoName": "selenoide952e551bb9395e16d060f28c54e5d31.mp4",
+                        "videoScreenSize": "1280x1024"
+                      },
+                      "container": "8489205e28c9781472e99c3921a6240de3894a3603ed9e187ad6360b6b013b8b",
+                      "containerInfo": {
+                        "id": "8489205e28c9781472e99c3921a6240de3894a3603ed9e187ad6360b6b013b8b",
+                        "ip": "172.17.0.4"
+                      },
+                      "id": "1345506093dfed8dbcef610da476911a228ca315978e5464ae49fb1142bbc49b",
+                      "screen": "1280x1024x24",
+                      "vnc": true
+                    }
+                  ]
+                }
+              }
+            },
+            "firefox": {
+              "59.0": {},
+              "63.0": {},
+              "64.0": {},
+              "latest": {}
+            },
+            "internet explorer": {
+              "11": {}
+            },
+            "opera": {
+              "56.0": {},
+              "latest": {}
+            },
+            "safari": {
+              "latest": {}
+            }
+          },
+          "pending": 0,
+          "queued": 0,
+          "total": 30,
+          "used": 1
+        }
         :return boolean (although in case of error in the request will be returned None)
         """
-        server_url_splitted = self.server_url.split(":")
-        host_url = "{}:{}:{}:{}/status".format(server_url_splitted[0], server_url_splitted[1], server_url_splitted[2], STATUS_PORT)
+        server_url_splitted = self.server_url.split(':')
+        host_url = '{}:{}:{}:{}/status'.format(server_url_splitted[0], server_url_splitted[1], server_url_splitted[2],
+                                               STATUS_PORT)
 
         try:
-            response = requests.get(host_url).json()["browsers"][self.browser]
+            response = requests.get(host_url).json()['browsers'][self.browser]
         except Exception as e:
-            self.driver_wrapper.logger.warn("the GGR status request has failed: \nResponse:  %s \nError message: %s\n" % (response.content, e))
+            self.driver_wrapper.logger.warning('the GGR status request has failed: \nResponse:  %s \n'
+                                               'Error message: %s\n' % (response.content, e))
             return None
         for browser in response:
             if response[browser] != {}:
-                sessions = response[browser][server_url_splitted[1].split("@")[0].replace("//", "")]["sessions"]
+                sessions = response[browser][server_url_splitted[1].split('@')[0].replace('//', '')]['sessions']
                 for session in sessions:
-                    if session["id"] == self.session_id:
+                    if session['id'] == self.session_id:
                         return True
         return False
 
