@@ -16,21 +16,17 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-# Python 2.7
-from __future__ import division
-
 import logging
 import os
-import time
-from io import open
-
 import requests
+import time
 from datetime import datetime
+from io import open
 from selenium.common.exceptions import NoSuchElementException, TimeoutException, StaleElementReferenceException
+from selenium.webdriver.common.action_chains import ActionChains
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support.ui import WebDriverWait
-from selenium.webdriver.common.action_chains import ActionChains
-from six.moves.urllib.parse import urlparse  # Python 2 and 3 compatibility
+from urllib.parse import urlparse
 
 from toolium.utils.path_utils import get_valid_filename, makedirs_safe
 
@@ -238,8 +234,8 @@ class Utils(object):
             return False
 
     def _expected_condition_find_element_stopped(self, element_times):
-        """Tries to find the element and checks that it has stopped moving, but does not thrown an exception if the element
-            is not found
+        """Tries to find the element and checks that it has stopped moving, but does not thrown an exception if the
+            element is not found
 
         :param element_times: Tuple with 2 items where:
             [0] element: PageElement or element locator as a tuple (locator_type, locator_value) to be found
@@ -257,8 +253,8 @@ class Utils(object):
             return False
 
     def _expected_condition_find_element_containing_text(self, element_text_pair):
-        """Tries to find the element and checks that it contains the specified text, but does not thrown an exception if the element is
-            not found
+        """Tries to find the element and checks that it contains the specified text, but does not thrown an exception if
+            the element is not found
 
         :param element_text_pair: Tuple with 2 items where:
             [0] element: PageElement or element locator as a tuple (locator_type, locator_value) to be found
@@ -459,7 +455,7 @@ class Utils(object):
         :param timeout: max time to wait
         """
         return self._wait_until(self._expected_condition_ajax_request_completed, None, timeout)
-    
+
     def get_remote_node(self):
         """Return the remote node that it's executing the actual test session
 
